==> seam-0.7.1-py3-none-any.whl: seam/routes/acs_credential_provisioning_automations.py <==
from seam.types import AbstractSeam as Seam
from seam.routes.types import (
    AbstractAcsCredentialProvisioningAutomations,
    AcsCredentialProvisioningAutomation,
)
from typing import Optional, Any, List, Dict, Union


class AcsCredentialProvisioningAutomations(
    AbstractAcsCredentialProvisioningAutomations
):
    seam: Seam

    def __init__(self, seam: Seam):
        self.seam = seam

    def launch(
        self,
        *,
        credential_manager_acs_system_id: str,
        user_identity_id: str,
        acs_credential_pool_id: Optional[str] = None,
        create_credential_manager_user: Optional[bool] = None,
        credential_manager_acs_user_id: Optional[str] = None
    ) -> AcsCredentialProvisioningAutomation:
        json_payload = {}

        if credential_manager_acs_system_id is not None:
            json_payload["credential_manager_acs_system_id"] = (
                credential_manager_acs_system_id
            )
        if user_identity_id is not None:
            json_payload["user_identity_id"] = user_identity_id
        if acs_credential_pool_id is not None:
            json_payload["acs_credential_pool_id"] = acs_credential_pool_id
        if create_credential_manager_user is not None:
            json_payload["create_credential_manager_user"] = (
                create_credential_manager_user
            )
        if credential_manager_acs_user_id is not None:
            json_payload["credential_manager_acs_user_id"] = (
                credential_manager_acs_user_id
            )

        res = self.seam.make_request(
            "POST", "/acs/credential_provisioning_automations/launch", json=json_payload
        )

        return AcsCredentialProvisioningAutomation.from_dict(
            res["acs_credential_provisioning_automation"]
        )

==> seam-0.8.0-py3-none-any.whl: seam/routes/acs_credential_provisioning_automations.py <==
from seam.types import AbstractSeam as Seam
from seam.routes.types import (
    AbstractAcsCredentialProvisioningAutomations,
    AcsCredentialProvisioningAutomation,
)
from typing import Optional, Any, List, Dict, Union


class AcsCredentialProvisioningAutomations(
    AbstractAcsCredentialProvisioningAutomations
):
    seam: Seam

    def __init__(self, seam: Seam):
        self.seam = seam

    def launch(
        self,
        *,
        credential_manager_acs_system_id: str,
        user_identity_id: str,
        acs_credential_pool_id: Optional[str] = None,
        create_credential_manager_user: Optional[bool] = None,
        credential_manager_acs_user_id: Optional[str] = None
    ) -> AcsCredentialProvisioningAutomation:
        json_payload = {}

        if credential_manager_acs_system_id is not None:
            json_payload["credential_manager_acs_system_id"] = (
                credential_manager_acs_system_id
            )
        if user_identity_id is not None:
            json_payload["user_identity_id"] = user_identity_id
        if acs_credential_pool_id is not None:
            json_payload["acs_credential_pool_id"] = acs_credential_pool_id
        if create_credential_manager_user is not None:
            json_payload["create_credential_manager_user"] = (
                create_credential_manager_user
            )
        if credential_manager_acs_user_id is not None:
            json_payload["credential_manager_acs_user_id"] = (
                credential_manager_acs_user_id
            )

        res = self.seam.client.post(
            "/acs/credential_provisioning_automations/launch", json=json_payload
        )

        return AcsCredentialProvisioningAutomation.from_dict(
            res["acs_credential_provisioning_automation"]
        )
